==> haskell-type-equality-1.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-equality.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-equality
version:              1.0.1
visibility:           public
id:                   type-equality-1.0.1-3TqCJMXiu3a6KLRuha0NIV
key:                  type-equality-1.0.1-3TqCJMXiu3a6KLRuha0NIV
license:              BSD-3-Clause
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>

author:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>, Martijn van Steenbergen

stability:            provisional
homepage:             https://github.com/hesselink/type-equality
synopsis:             Data.Type.Equality compat package
description:
    This library defines a propositional equality data type,
    shims @Data.Type.Equality@ as well as possible for older GHCs (< 7.8).

    @
    data a :~: b where
    \    Refl :: a :~: a
    @

    The module @Data.Type.Equality.Hetero@ shims @:~~:@ equality, for
    compilers with @PolyKinds@

category:             Data, Dependent Types
abi:                  54d3c03809481d4ac5f0536725e9ce8e
exposed:              True
exposed-modules:      Data.Type.Equality.Hetero
import-dirs:          /usr/lib/ghc-9.2.8/site-local/type-equality-1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/type-equality-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-equality
hs-libraries:         HStype-equality-1.0.1-3TqCJMXiu3a6KLRuha0NIV
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-type-equality/html/type-equality.haddock

haddock-html:         /usr/share/doc/haskell-type-equality/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-equality-1.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-equality.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-equality
version:              1.0.1
visibility:           public
id:                   type-equality-1.0.1-K21FM4L6EuWJh4TZhbnUUX
key:                  type-equality-1.0.1-K21FM4L6EuWJh4TZhbnUUX
license:              BSD-3-Clause
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>

author:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>, Martijn van Steenbergen

stability:            provisional
homepage:             https://github.com/hesselink/type-equality
synopsis:             Data.Type.Equality compat package
description:
    This library defines a propositional equality data type,
    shims @Data.Type.Equality@ as well as possible for older GHCs (< 7.8).

    @
    data a :~: b where
    \    Refl :: a :~: a
    @

    The module @Data.Type.Equality.Hetero@ shims @:~~:@ equality, for
    compilers with @PolyKinds@

category:             Data, Dependent Types
abi:                  97cb526450372c8d198e4f00d65d53cc
exposed:              True
exposed-modules:      Data.Type.Equality.Hetero
import-dirs:          /usr/lib/ghc-9.4.8/site-local/type-equality-1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/type-equality-1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/type-equality-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-equality
hs-libraries:         HStype-equality-1.0.1-K21FM4L6EuWJh4TZhbnUUX
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-type-equality/html/type-equality.haddock

haddock-html:         /usr/share/doc/haskell-type-equality/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
